@@ -1,15 +1,20 @@
+// Copyright Amazon.com, Inc. or its affiliates.
+
 //! This module provides the necessary structures and logic to read values from a binary Ion
 //! data stream.
 
+pub mod binary_writer;
 pub(crate) mod constants;
-pub(crate) mod cursor;
+pub mod decimal;
 mod header;
 mod int;
 mod nibbles;
+pub(crate) mod raw_binary_reader;
+pub mod raw_binary_writer;
+pub mod timestamp;
 mod type_code;
-mod uint;
+pub mod uint;
 mod var_int;
 mod var_uint;
-pub mod writer;
 
-pub(crate) use type_code::IonTypeCode;
+pub use type_code::IonTypeCode;
