@@ -16,21 +16,34 @@ macro_rules! try_to {
 pub mod result;
 
 pub mod binary;
-pub mod cursor;
 pub mod data_source;
+pub mod raw_reader;
 pub mod text;
 pub mod types;
 pub mod value;
 
 pub mod constants;
+mod raw_symbol_token;
+mod raw_symbol_token_ref;
 mod reader;
+mod stream_reader;
 mod symbol_table;
-mod system_event_handler;
+mod system_reader;
+mod writer;
 
-pub use binary::cursor::BinaryIonCursor;
-pub use cursor::Cursor;
+pub use binary::raw_binary_reader::RawBinaryReader;
 pub use data_source::IonDataSource;
+pub use raw_reader::RawStreamItem;
 pub use reader::Reader;
+pub use reader::StreamItem;
+pub use stream_reader::StreamReader;
 pub use symbol_table::SymbolTable;
-pub use system_event_handler::SystemEventHandler;
+pub use system_reader::{SystemReader, SystemStreamItem};
 pub use types::IonType;
+
+/// Re-exports of third party dependencies that are part of our public API.
+///
+/// See also: https://github.com/amzn/ion-rust/issues/302.
+pub mod external {
+    pub use bigdecimal;
+}
