@@ -11,7 +11,7 @@ pub mod timestamp;
 
 use crate::result::{illegal_operation, IonError};
 use ion_c_sys::ION_TYPE;
-use std::convert::TryFrom;
+use std::{convert::TryFrom, fmt};
 
 /// Represents the Ion data type of a given value. To learn more about each data type,
 /// read [the Ion Data Model](http://amzn.github.io/ion-docs/docs/spec.html#the-ion-data-model)
@@ -33,13 +33,34 @@ pub enum IonType {
     Struct,
 }
 
+impl fmt::Display for IonType {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(
+            f,
+            "{}",
+            match self {
+                IonType::Null => "null",
+                IonType::Boolean => "boolean",
+                IonType::Integer => "integer",
+                IonType::Float => "float",
+                IonType::Decimal => "decimal",
+                IonType::Timestamp => "timestamp",
+                IonType::Symbol => "symbol",
+                IonType::String => "string",
+                IonType::Clob => "clob",
+                IonType::Blob => "blob",
+                IonType::List => "list",
+                IonType::SExpression => "sexp",
+                IonType::Struct => "struct",
+            }
+        )
+    }
+}
+
 impl IonType {
     pub fn is_container(&self) -> bool {
         use IonType::*;
-        match self {
-            List | SExpression | Struct => true,
-            _ => false,
-        }
+        matches!(self, List | SExpression | Struct)
     }
 }
 
@@ -67,10 +88,10 @@ impl TryFrom<ION_TYPE> for IonType {
     }
 }
 
-impl Into<ION_TYPE> for IonType {
-    fn into(self) -> ION_TYPE {
+impl From<IonType> for ION_TYPE {
+    fn from(ion_type: IonType) -> ION_TYPE {
         use IonType::*;
-        match self {
+        match ion_type {
             Null => ion_c_sys::ION_TYPE_NULL,
             Boolean => ion_c_sys::ION_TYPE_BOOL,
             Integer => ion_c_sys::ION_TYPE_INT,
