@@ -1,6 +1,9 @@
 use crate::result::{illegal_operation, illegal_operation_raw, IonError, IonResult};
 use crate::types::decimal::Decimal;
-use chrono::{DateTime, Datelike, FixedOffset, NaiveDate, NaiveDateTime, TimeZone, Timelike};
+use crate::types::magnitude::Magnitude;
+use chrono::{
+    DateTime, Datelike, FixedOffset, LocalResult, NaiveDate, NaiveDateTime, TimeZone, Timelike,
+};
 use ion_c_sys::timestamp::{IonDateTime, TSOffsetKind, TSPrecision};
 use std::convert::TryInto;
 use std::fmt::Debug;
@@ -75,10 +78,10 @@ fn number_of_digits(value: u32) -> u32 {
 /// of an arbitrary unit.
 #[derive(Debug, Clone)]
 pub struct Timestamp {
-    date_time: NaiveDateTime,
-    offset: Option<FixedOffset>,
-    precision: Precision,
-    fractional_seconds: Option<Mantissa>,
+    pub(crate) date_time: NaiveDateTime,
+    pub(crate) offset: Option<FixedOffset>,
+    pub(crate) precision: Precision,
+    pub(crate) fractional_seconds: Option<Mantissa>,
 }
 
 // TODO: Timestamp does not yet provide useful accessors for its individual fields. It can be
@@ -100,6 +103,81 @@ impl Timestamp {
         timestamp
     }
 
+    /// If the precision is [Precision::FractionalSeconds], returns a Decimal scale
+    /// of this Timestamp's fractional seconds; otherwise, returns None.
+    ///
+    /// For example, a Timestamp with 553 milliseconds would return a Decimal scale of 3.
+    pub fn fractional_seconds_scale(&self) -> Option<i64> {
+        // This function is used when comparing two Timestamps with different Mantissa representations.
+        use Mantissa::*;
+        match self.fractional_seconds.as_ref() {
+            // number_of_digits represent number of digits of precision in the Timestamp's fractional seconds.
+            // this is equivalent to the decimal scale when we convert the fractional seconds into a decimal
+            // and return its scale
+            Some(Digits(number_of_digits)) => Some(*number_of_digits as i64),
+            // This timestamp already stores its fractional seconds as a Decimal; return the scale of this Decimal.
+            Some(Arbitrary(decimal)) => Some(decimal.scale()),
+            // This Timestamp's precision is too low to have a fractional seconds field.
+            None => None,
+        }
+    }
+
+    /// If the precision is [Precision::FractionalSeconds], returns a Decimal representation
+    /// of this Timestamp's fractional seconds; otherwise, returns None.
+    ///
+    /// For example, a Timestamp with 553 milliseconds would return a Decimal with
+    /// coefficient 553, exponent -3.
+    fn fractional_seconds_as_decimal(&self) -> Option<Decimal> {
+        // This function is used when comparing two Timestamps with different Mantissa representations.
+        use Mantissa::*;
+        match self.fractional_seconds.as_ref() {
+            // This timestamp stores its fractional seconds in its `date_time` field.
+            // We'll need to convert the date_time's nanoseconds to a Decimal and return it.
+            Some(Digits(number_of_digits)) => {
+                let coefficient = first_n_digits_of(*number_of_digits, self.date_time.nanosecond());
+                let exponent = -((coefficient as f64).log10().ceil() as i64);
+                Some(Decimal::new(coefficient, exponent))
+            }
+            // This timestamp already stores its fractional seconds as a Decimal; return a clone.
+            Some(Arbitrary(decimal)) => Some(decimal.clone()),
+            // This Timestamp's precision is too low to have a fractional seconds field.
+            None => None,
+        }
+    }
+
+    /// If the precision is [Precision::FractionalSeconds], returns a u32 representing
+    /// this Timestamp's fractional seconds in nanoseconds; otherwise, returns None.
+    ///
+    /// NOTE: This is a potentially lossy operation. A Timestamp with picoseconds would return a
+    /// number of nanoseconds, losing precision. Similarly, a Timestamp with milliseconds would
+    /// also return a number of nanoseconds, erroneously gaining precision.
+    fn fractional_seconds_as_nanoseconds(&self) -> Option<u32> {
+        // This function is used when converting a Timestamp to a DateTime<FixedOffset> or
+        // NaiveDateTime.
+        use Mantissa::*;
+        match self.fractional_seconds.as_ref() {
+            // This timestamp already stores its fractional seconds in its `date_time` field.
+            // We can ignore the `number_of_digits` (which tracks its precision) and simply return
+            // `self.date_time`'s nanoseconds.
+            Some(Digits(_number_of_digits)) => Some(self.date_time.nanosecond()),
+            // This timestamp stores its fractional seconds as a Decimal. Down-convert it to a u32.
+            Some(Arbitrary(decimal)) => {
+                const NANOSECONDS_EXPONENT: i64 = -9;
+                let exponent_delta = decimal.exponent - NANOSECONDS_EXPONENT;
+                let magnitude = match decimal.coefficient.magnitude() {
+                    Magnitude::U64(magnitude) => magnitude,
+                    Magnitude::BigUInt(_magnitude) => {
+                        todo!("convert decimal fractional seconds with BigUInt magnitudes to nanoseconds")
+                    }
+                };
+                let nanoseconds = (*magnitude as f64 * 10f64.powi(exponent_delta as i32)) as u32;
+                Some(nanoseconds)
+            }
+            // This Timestamp's precision is too low to have a fractional seconds field.
+            None => None,
+        }
+    }
+
     /// Tests the fractional seconds fields of two timestamps for equality. This function will
     /// only be called if both Timestamps have a precision of [Precision::FractionalSeconds].
     fn fractional_seconds_equal(&self, other: &Timestamp) -> bool {
@@ -121,18 +199,11 @@ impl Timestamp {
                 d1 == d2
             }
             (Some(Arbitrary(d1)), Some(Arbitrary(d2))) => d1.eq(d2),
-            //TODO: I believe that the public API makes it impossible for a user to create a
-            //      Timestamp with a Mantissa::Arbitrary(_) unless it is required. If this is
-            //      correct, the following two cases can be reduced to `false`, as two Timestamps
-            //      using different Mantissa variants are inherently unequal. Both of these
-            //      branches currently allocate, so this would be a worthwhile optimization.
-            (Some(Digits(d1)), Some(Arbitrary(d2))) => {
-                let upgraded: Decimal = (*d1).into();
-                upgraded.eq(d2)
+            (Some(Digits(_d1)), Some(Arbitrary(d2))) => {
+                d2.eq(&self.fractional_seconds_as_decimal().unwrap())
             }
-            (Some(Arbitrary(d1)), Some(Digits(d2))) => {
-                let upgraded: Decimal = (*d2).into();
-                d1.eq(&upgraded)
+            (Some(Arbitrary(d1)), Some(Digits(_d2))) => {
+                d1.eq(&other.fractional_seconds_as_decimal().unwrap())
             }
         }
     }
@@ -148,9 +219,10 @@ impl Timestamp {
 
     /// Creates a TimestampBuilder with the specified year and [Precision::Year].
     pub fn with_year(year: u32) -> MonthSetter {
-        let mut builder: TimestampBuilder = Default::default();
-        builder.precision = Precision::Year;
-        builder.year = year as u16;
+        let builder: TimestampBuilder = TimestampBuilder {
+            year: year as u16,
+            ..Default::default()
+        };
         MonthSetter { builder }
     }
 
@@ -197,6 +269,17 @@ impl Timestamp {
             .into_builder();
         FractionalSecondSetter { builder }
     }
+
+    /// Returns the offset in minutes that has been specified in the [Timestamp].
+    /// A positive value indicates Eastern Hemisphere, while a negative value indicates Western Hemisphere.
+    pub fn offset(&self) -> Option<i32> {
+        self.offset.map(|offset| offset.local_minus_utc() / 60)
+    }
+
+    /// Returns the precision that has been specified in the [Timestamp].
+    pub fn precision(&self) -> Precision {
+        self.precision
+    }
 }
 
 impl PartialEq for Timestamp {
@@ -250,6 +333,7 @@ impl PartialEq for Timestamp {
 // See the unit tests for usage examples.
 #[derive(Debug, Clone, Default)]
 struct TimestampBuilder {
+    fields_are_utc: bool,
     precision: Precision,
     offset: Option<i32>,
     year: u16,
@@ -331,31 +415,82 @@ impl TimestampBuilder {
         Ok(datetime)
     }
 
+    // A [NaiveDateTime] has no offset. This function attempts to apply the provided offset to the
+    // NaiveDateTime, producing a DateTime<FixedOffset>. If the offset is invalid or the combination
+    // of offset and datetime would produce an invalid Timestamp, this function will return Err.
+    fn apply_offset(
+        offset_minutes: i32,
+        fields_are_utc: bool,
+        datetime: NaiveDateTime,
+    ) -> IonResult<DateTime<FixedOffset>> {
+        // The chrono APIs express their DateTime offsets in seconds, but the Ion APIs use minutes.
+        const SECONDS_PER_MINUTE: i32 = 60;
+        let offset_seconds = offset_minutes * SECONDS_PER_MINUTE;
+        let offset = FixedOffset::east_opt(offset_seconds).ok_or_else(|| {
+            illegal_operation_raw(format!(
+                "specified offset ({} minutes) is invalid",
+                offset_minutes
+            ))
+        })?;
+
+        // If the fields of the datetime are UTC, constructing a DateTime<FixedOffset> is guaranteed
+        // to succeed. Return it directly.
+        if fields_are_utc {
+            return Ok(offset.from_utc_datetime(&datetime));
+        }
+
+        // Otherwise, apply the offset to our (local) NaiveDateTime and make sure the resulting
+        // DateTime<FixedOffset> is valid.
+        return match offset.from_local_datetime(&datetime) {
+            LocalResult::None => {
+                illegal_operation(
+                    format!(
+                        "specified offset/datetime pair is invalid (offset={}, datetime={})",
+                        offset_minutes,
+                        datetime
+                    )
+                )
+            },
+            LocalResult::Single(datetime) => Ok(datetime),
+            LocalResult::Ambiguous(_min, _max) => {
+                illegal_operation(
+                    format!(
+                        "specified offset/datetime pair produces an ambiguous timestamp (offset={}, datetime={})",
+                        offset_minutes,
+                        datetime
+                    )
+                )
+            }
+        };
+    }
+
     /// Attempt to construct a [Timestamp] using the values configured on the [TimestampBuilder].
     /// If any of the individual fields are invalid (for example, a `month` value that is greater
     /// than `12`) or if the resulting timestamp would represent a non-existent point in time
     /// (like those bypassed by daylight saving time), this method will return an `Err(IonError)`.
     fn build(mut self) -> IonResult<Timestamp> {
-        if let Some(offset) = self.offset {
-            let offset = FixedOffset::west_opt(offset).ok_or_else(|| {
-                illegal_operation_raw(format!("specified offset ('{}') is invalid", offset))
-            })?;
-            let mut datetime: DateTime<FixedOffset> = offset.ymd(0, 1, 1).and_hms_nano(0, 0, 0, 0);
-            datetime = self.configure_datetime(datetime)?;
-            let mut timestamp = Timestamp::from_datetime(datetime, self.precision);
-            if self.precision == Precision::FractionalSeconds {
-                timestamp.fractional_seconds = self.fractional_seconds;
-            }
-            Ok(timestamp)
+        // Start with a clean slate NaiveDateTime that we can configure. (These are cheap to copy.)
+        let mut datetime: NaiveDateTime = NaiveDate::from_ymd(0, 1, 1).and_hms_nano(0, 0, 0, 0);
+        // Set all of the time fields on the datetime using the data from our TimestampBuilder
+        datetime = self.configure_datetime(datetime)?;
+        // If the timestamp we're building has a known offset...
+        let mut timestamp: Timestamp = if let Some(offset_minutes) = self.offset {
+            // ...apply the offset to our NaiveDateTime, producing a DateTime<FixedOffset>
+            let datetime_with_offset: DateTime<FixedOffset> =
+                Self::apply_offset(offset_minutes, self.fields_are_utc, datetime)?;
+            // ...and convert the DateTime<FixedOffset> into a full Timestamp.
+            Timestamp::from_datetime(datetime_with_offset, self.precision)
         } else {
-            let mut datetime: NaiveDateTime = NaiveDate::from_ymd(0, 1, 1).and_hms_nano(0, 0, 0, 0);
-            datetime = self.configure_datetime(datetime)?;
-            let mut timestamp = Timestamp::from_datetime(datetime, self.precision);
-            if self.precision == Precision::FractionalSeconds {
-                timestamp.fractional_seconds = self.fractional_seconds;
-            }
-            Ok(timestamp)
+            // Otherwise, there's not a known offset. We can directly convert our NaiveDateTime
+            // into a full Timestamp.
+            Timestamp::from_datetime(datetime, self.precision)
+        };
+
+        // Copy the fractional seconds from the builder to the Timestamp.
+        if self.precision == Precision::FractionalSeconds {
+            timestamp.fractional_seconds = self.fractional_seconds;
         }
+        Ok(timestamp)
     }
 }
 
@@ -469,11 +604,23 @@ impl SecondSetter {
         FractionalSecondSetter { builder }
     }
 
+    /// Sets the difference, in minutes, from UTC. A positive value indicates
+    /// Eastern Hemisphere, while a negative value indicates Western Hemisphere.
+    // The unit (minutes) could be seconds (which is what the chrono crate uses
+    // internally), but Ion uses minutes in its binary representation, so it
+    // makes sense to be consistent.
     pub fn build_at_offset(mut self, offset_minutes: i32) -> IonResult<Timestamp> {
         self.builder.offset = Some(offset_minutes);
         self.into_builder().build()
     }
 
+    /// Like [build_at_offset], but the fields provided for each time unit are understood
+    /// to be in UTC rather than in the local time of the specified offset.
+    pub fn build_utc_fields_at_offset(mut self, offset_minutes: i32) -> IonResult<Timestamp> {
+        self.builder.fields_are_utc = true;
+        self.build_at_offset(offset_minutes)
+    }
+
     pub fn build_at_unknown_offset(mut self) -> IonResult<Timestamp> {
         self.builder.offset = None;
         self.into_builder().build()
@@ -539,6 +686,13 @@ impl FractionalSecondSetter {
         self.into_builder().build()
     }
 
+    /// Like [build_at_offset], but the fields provided for each time unit are understood
+    /// to be in UTC rather than in the local time of the specified offset.
+    pub fn build_utc_fields_at_offset(mut self, offset_minutes: i32) -> IonResult<Timestamp> {
+        self.builder.fields_are_utc = true;
+        self.build_at_offset(offset_minutes)
+    }
+
     pub fn build_at_unknown_offset(mut self) -> IonResult<Timestamp> {
         self.builder.offset = None;
         self.into_builder().build()
@@ -565,6 +719,50 @@ impl_time_unit_setter_for!(HourAndMinuteSetter);
 impl_time_unit_setter_for!(SecondSetter);
 impl_time_unit_setter_for!(FractionalSecondSetter);
 
+fn downconvert_to_naive_datetime_with_nanoseconds(timestamp: &Timestamp) -> NaiveDateTime {
+    if timestamp.precision == Precision::FractionalSeconds {
+        // DateTime always uses nanosecond precision. If our Timestamp uses a Decimal for
+        // its fractional seconds, attempt to convert it to a number of nanoseconds.
+        // This operation may add or lose precision, but is necessary to conform with
+        // chrono's expectations.
+        let nanoseconds = timestamp.fractional_seconds_as_nanoseconds().unwrap();
+        // Copy `self.date_time` and set the copy's nanoseconds to this new value.
+        // Modifying the nanoseconds should never be invalid.
+        timestamp.date_time.with_nanosecond(nanoseconds).unwrap()
+    } else {
+        // NaiveDateTime implements `Copy`
+        timestamp.date_time
+    }
+}
+
+// Allows a Timestamp with an unknown offset to be converted to a NaiveDateTime.
+impl TryInto<NaiveDateTime> for Timestamp {
+    type Error = IonError;
+
+    fn try_into(self) -> Result<NaiveDateTime, Self::Error> {
+        if self.offset.is_some() {
+            return illegal_operation(
+                "cannot convert a Timestamp with a known offset into a NaiveDateTime",
+            );
+        }
+        Ok(downconvert_to_naive_datetime_with_nanoseconds(&self))
+    }
+}
+
+impl TryInto<DateTime<FixedOffset>> for Timestamp {
+    type Error = IonError;
+
+    fn try_into(self) -> Result<DateTime<FixedOffset>, Self::Error> {
+        if self.offset.is_none() {
+            return illegal_operation(
+                "cannot convert a Timestamp with an unknown offset into a DateTime<FixedOffset>",
+            );
+        }
+        let date_time = downconvert_to_naive_datetime_with_nanoseconds(&self);
+        Ok(self.offset.unwrap().from_utc_datetime(&date_time))
+    }
+}
+
 // Allows a NaiveDateTime to be converted to a Timestamp with an unknown offset.
 impl From<NaiveDateTime> for Timestamp {
     fn from(date_time: NaiveDateTime) -> Self {
@@ -600,7 +798,7 @@ impl From<ion_c_sys::timestamp::IonDateTime> for Timestamp {
         use ion_c_sys::timestamp::Mantissa as IonCMantissa;
 
         let offset = match ionc_dt.offset_kind() {
-            TSOffsetKind::KnownOffset => Some(ionc_dt.as_datetime().offset().clone()),
+            TSOffsetKind::KnownOffset => Some(*ionc_dt.as_datetime().offset()),
             TSOffsetKind::UnknownOffset => None,
         };
         let precision = match ionc_dt.precision() {
@@ -656,9 +854,9 @@ impl TryInto<ion_c_sys::timestamp::IonDateTime> for Timestamp {
             }
             _ => {
                 // invariant violation
-                return illegal_operation(format!(
-                    "Could not convert timestamp with fractional seconds and no mantissa"
-                ));
+                return illegal_operation(
+                    "Could not convert timestamp with fractional seconds and no mantissa",
+                );
             }
         };
         let date_time = offset.from_utc_datetime(&self.date_time);
@@ -670,13 +868,16 @@ impl TryInto<ion_c_sys::timestamp::IonDateTime> for Timestamp {
 #[cfg(test)]
 mod timestamp_tests {
     use crate::result::IonResult;
+    use crate::types::decimal::Decimal;
     use crate::types::timestamp::{Mantissa, Precision, Timestamp};
+    use chrono::{DateTime, FixedOffset, NaiveDate, NaiveDateTime, TimeZone, Timelike};
+    use std::convert::TryInto;
 
     #[test]
     fn test_timestamps_with_same_ymd_hms_millis_at_known_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms_millis(2021, 2, 5, 16, 43, 51, 192);
-        let timestamp1 = builder.clone().build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder.clone().build_at_offset(5 * 60 * 60)?;
+        let timestamp1 = builder.clone().build_at_offset(5 * 60)?;
+        let timestamp2 = builder.build_at_offset(5 * 60)?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -685,7 +886,7 @@ mod timestamp_tests {
     fn test_timestamps_with_same_ymd_hms_millis_at_unknown_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms_millis(2021, 2, 5, 16, 43, 51, 192);
         let timestamp1 = builder.clone().build_at_unknown_offset()?;
-        let timestamp2 = builder.clone().build_at_unknown_offset()?;
+        let timestamp2 = builder.build_at_unknown_offset()?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -693,8 +894,32 @@ mod timestamp_tests {
     #[test]
     fn test_timestamps_with_same_ymd_hms_at_known_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms(2021, 2, 5, 16, 43, 51);
-        let timestamp1 = builder.clone().build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder.clone().build_at_offset(5 * 60 * 60)?;
+        let timestamp1 = builder.clone().build_at_offset(5 * 60)?;
+        let timestamp2 = builder.build_at_offset(5 * 60)?;
+        assert_eq!(timestamp1, timestamp2);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamps_from_utc_and_local_hm_fields_at_same_offset_are_equal() -> IonResult<()> {
+        // Builder 1 specifies its time fields in the local time of the specified offset
+        let builder1 = Timestamp::with_ymd(2021, 2, 5).with_hour_and_minute(11, 43);
+        let timestamp1 = builder1.build_at_offset(-5 * 60)?;
+        // Builder 2 specifies its time fields in UTC and expects the offset to be applied afterwards
+        let builder2 = Timestamp::with_ymd(2021, 2, 5).with_hour_and_minute(16, 43);
+        let timestamp2 = builder2.build_utc_fields_at_offset(-5 * 60)?;
+        assert_eq!(timestamp1, timestamp2);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamps_from_utc_and_local_hms_fields_at_same_offset_are_equal() -> IonResult<()> {
+        // Builder 1 specifies its time fields in the local time of the specified offset
+        let builder1 = Timestamp::with_ymd_hms(2021, 2, 5, 11, 43, 51);
+        let timestamp1 = builder1.build_at_offset(-5 * 60)?;
+        // Builder 2 specifies its time fields in UTC and expects the offset to be applied afterwards
+        let builder2 = Timestamp::with_ymd_hms(2021, 2, 5, 16, 43, 51);
+        let timestamp2 = builder2.build_utc_fields_at_offset(-5 * 60)?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -703,7 +928,7 @@ mod timestamp_tests {
     fn test_timestamps_with_same_ymd_hms_at_unknown_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms(2021, 2, 5, 16, 43, 51);
         let timestamp1 = builder.clone().build_at_unknown_offset()?;
-        let timestamp2 = builder.clone().build_at_unknown_offset()?;
+        let timestamp2 = builder.build_at_unknown_offset()?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -711,8 +936,8 @@ mod timestamp_tests {
     #[test]
     fn test_timestamps_with_same_ymd_hm_at_known_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd(2021, 2, 5).with_hour_and_minute(16, 43);
-        let timestamp1 = builder.clone().build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder.clone().build_at_offset(5 * 60 * 60)?;
+        let timestamp1 = builder.clone().build_at_offset(5 * 60)?;
+        let timestamp2 = builder.build_at_offset(5 * 60)?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -721,7 +946,7 @@ mod timestamp_tests {
     fn test_timestamps_with_same_ymd_hm_at_unknown_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd(2021, 2, 5).with_hour_and_minute(16, 43);
         let timestamp1 = builder.clone().build_at_unknown_offset()?;
-        let timestamp2 = builder.clone().build_at_unknown_offset()?;
+        let timestamp2 = builder.build_at_unknown_offset()?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -730,7 +955,7 @@ mod timestamp_tests {
     fn test_timestamps_with_same_ymd_at_unknown_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd(2021, 2, 5);
         let timestamp1 = builder.clone().build()?;
-        let timestamp2 = builder.clone().build()?;
+        let timestamp2 = builder.build()?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -739,7 +964,7 @@ mod timestamp_tests {
     fn test_timestamps_with_same_ym_at_unknown_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_year(2021).with_month(2);
         let timestamp1 = builder.clone().build()?;
-        let timestamp2 = builder.clone().build()?;
+        let timestamp2 = builder.build()?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -748,7 +973,7 @@ mod timestamp_tests {
     fn test_timestamps_with_same_year_at_unknown_offset_are_equal() -> IonResult<()> {
         let builder = Timestamp::with_year(2021);
         let timestamp1 = builder.clone().build()?;
-        let timestamp2 = builder.clone().build()?;
+        let timestamp2 = builder.build()?;
         assert_eq!(timestamp1, timestamp2);
         Ok(())
     }
@@ -756,8 +981,8 @@ mod timestamp_tests {
     #[test]
     fn test_timestamps_at_different_offsets_are_not_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms_millis(2021, 2, 5, 16, 43, 51, 192);
-        let timestamp1 = builder.clone().build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder.clone().build_at_offset(4 * 60 * 60)?;
+        let timestamp1 = builder.clone().build_at_offset(5 * 60)?;
+        let timestamp2 = builder.build_at_offset(4 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -765,8 +990,8 @@ mod timestamp_tests {
     #[test]
     fn test_timestamps_with_known_and_unknown_offsets_are_not_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms_millis(2021, 2, 5, 16, 43, 51, 192);
-        let timestamp1 = builder.clone().build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder.clone().build_at_unknown_offset()?;
+        let timestamp1 = builder.clone().build_at_offset(5 * 60)?;
+        let timestamp2 = builder.build_at_unknown_offset()?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -774,11 +999,8 @@ mod timestamp_tests {
     #[test]
     fn test_timestamps_with_different_precisions_are_not_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd_hms(2021, 2, 5, 16, 43, 51);
-        let timestamp1 = builder.clone().build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder
-            .clone()
-            .with_milliseconds(192)
-            .build_at_offset(5 * 60 * 60)?;
+        let timestamp1 = builder.clone().build_at_offset(5 * 60)?;
+        let timestamp2 = builder.with_milliseconds(192).build_at_offset(5 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -789,12 +1011,11 @@ mod timestamp_tests {
         let timestamp1 = builder
             .clone()
             .with_milliseconds(192)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
         // The microseconds field has the same amount of time, but a different precision.
         let timestamp2 = builder
-            .clone()
             .with_microseconds(193 * 1_000)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -805,11 +1026,8 @@ mod timestamp_tests {
         let timestamp1 = builder
             .clone()
             .with_milliseconds(192)
-            .build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder
-            .clone()
-            .with_milliseconds(193)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
+        let timestamp2 = builder.with_milliseconds(193).build_at_offset(5 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -817,14 +1035,8 @@ mod timestamp_tests {
     #[test]
     fn test_timestamps_with_different_seconds_are_not_equal() -> IonResult<()> {
         let builder = Timestamp::with_ymd(2021, 2, 5).with_hour_and_minute(16, 43);
-        let timestamp1 = builder
-            .clone()
-            .with_second(12)
-            .build_at_offset(5 * 60 * 60)?;
-        let timestamp2 = builder
-            .clone()
-            .with_second(13)
-            .build_at_offset(5 * 60 * 60)?;
+        let timestamp1 = builder.clone().with_second(12).build_at_offset(5 * 60)?;
+        let timestamp2 = builder.with_second(13).build_at_offset(5 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -835,11 +1047,10 @@ mod timestamp_tests {
         let timestamp1 = builder
             .clone()
             .with_hour_and_minute(16, 42)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
         let timestamp2 = builder
-            .clone()
             .with_hour_and_minute(16, 43)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -850,11 +1061,10 @@ mod timestamp_tests {
         let timestamp1 = builder
             .clone()
             .with_hour_and_minute(16, 42)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
         let timestamp2 = builder
-            .clone()
             .with_hour_and_minute(17, 42)
-            .build_at_offset(5 * 60 * 60)?;
+            .build_at_offset(5 * 60)?;
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -863,7 +1073,7 @@ mod timestamp_tests {
     fn test_timestamps_with_different_days_are_not_equal() -> IonResult<()> {
         let builder = Timestamp::with_year(2021).with_month(2);
         let timestamp1 = builder.clone().with_day(5).build();
-        let timestamp2 = builder.clone().with_day(6).build();
+        let timestamp2 = builder.with_day(6).build();
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -872,7 +1082,7 @@ mod timestamp_tests {
     fn test_timestamps_with_different_months_are_not_equal() -> IonResult<()> {
         let builder = Timestamp::with_year(2021);
         let timestamp1 = builder.clone().with_month(2).build();
-        let timestamp2 = builder.clone().with_month(3).build();
+        let timestamp2 = builder.with_month(3).build();
         assert_ne!(timestamp1, timestamp2);
         Ok(())
     }
@@ -885,6 +1095,82 @@ mod timestamp_tests {
         Ok(())
     }
 
+    #[test]
+    fn test_timestamp_try_into_naive_datetime() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0).build_at_unknown_offset()?;
+        let naive_datetime: NaiveDateTime = timestamp.try_into()?;
+        let expected = NaiveDate::from_ymd(2021, 4, 6).and_hms(10, 15, 0);
+        assert_eq!(expected, naive_datetime);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_try_into_naive_datetime_fractional_seconds() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0)
+            .with_milliseconds(449)
+            .build_at_unknown_offset()?;
+        let datetime: NaiveDateTime = timestamp.try_into()?;
+        let naive_datetime = NaiveDate::from_ymd(2021, 4, 6)
+            .and_hms(10, 15, 0)
+            .with_nanosecond(449000000)
+            .unwrap();
+        assert_eq!(datetime, naive_datetime);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_try_into_naive_datetime_error() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 1, 1, 0, 0, 0).build_at_offset(0)?;
+        //     ^---- This timestamp has a known offset, so we cannot convert it into a NaiveDateTime
+        let result: IonResult<NaiveDateTime> = timestamp.try_into();
+        assert!(result.is_err());
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_try_into_fixed_offset_datetime() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0).build_at_offset(-5 * 60)?;
+        //                    ^-- Timestamp's offset API takes minutes
+        let datetime: DateTime<FixedOffset> = timestamp.try_into()?;
+        // chrono's FixedOffset takes seconds ----------v
+        let expected_offset = FixedOffset::east(-5 * 60 * 60);
+        let naive_datetime = NaiveDate::from_ymd(2021, 4, 6).and_hms(10, 15, 0);
+        let expected_datetime = expected_offset
+            .from_local_datetime(&naive_datetime)
+            .unwrap();
+        assert_eq!(datetime, expected_datetime);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_try_into_fixed_offset_datetime_fractional_seconds() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0)
+            .with_milliseconds(449)
+            .build_at_offset(-5 * 60)?;
+        //                    ^-- Timestamp's offset API takes minutes
+        let datetime: DateTime<FixedOffset> = timestamp.try_into()?;
+        // chrono's FixedOffset takes seconds ----------v
+        let expected_offset = FixedOffset::east(-5 * 60 * 60);
+        let naive_datetime = NaiveDate::from_ymd(2021, 4, 6)
+            .and_hms(10, 15, 0)
+            .with_nanosecond(449000000)
+            .unwrap();
+        let expected_datetime = expected_offset
+            .from_local_datetime(&naive_datetime)
+            .unwrap();
+        assert_eq!(datetime, expected_datetime);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_try_into_datetime_fixedoffset_error() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 1, 1, 0, 0, 0).build_at_unknown_offset()?;
+        //     ^---- This timestamp has an unknown offset, so we cannot convert it into a DateTime<FixedOffset>
+        let result: IonResult<DateTime<FixedOffset>> = timestamp.try_into();
+        assert!(result.is_err());
+        Ok(())
+    }
+
     #[test]
     fn test_timestamp_builder() {
         // Using individual field setters produces the same Timestamp as using setters
@@ -914,6 +1200,61 @@ mod timestamp_tests {
         assert_eq!(timestamp2, timestamp3);
     }
 
+    #[test]
+    fn test_timestamp_fixed_offset() -> IonResult<()> {
+        let timestamp = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0)
+            .with_milliseconds(449)
+            .build_at_offset(-5 * 60)?;
+        //                    ^-- Timestamp's offset API takes minutes
+        // expected offset in minutes
+        let expected_offset = -5 * 60;
+
+        assert_eq!(timestamp.offset().unwrap(), expected_offset);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_precision() -> IonResult<()> {
+        let timestamp = Timestamp::with_year(2021).with_month(2).build()?;
+        assert_eq!(timestamp.precision(), Precision::Month);
+        Ok(())
+    }
+
+    #[test]
+    fn test_timestamp_fractional_seconds_scale() -> IonResult<()> {
+        // Set fractional seconds as Decimal
+        let timestamp_with_micro_seconds = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0)
+            .with_fractional_seconds(Decimal::new(553u64, -6))
+            .build_at_offset(-5 * 60)?;
+
+        assert_eq!(
+            timestamp_with_micro_seconds
+                .fractional_seconds_scale()
+                .unwrap(),
+            6
+        );
+
+        // Set fractional seconds with milliseconds
+        let timestamp_with_milliseconds = Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0)
+            .with_milliseconds(449)
+            .build_at_offset(-5 * 60)?;
+
+        assert_eq!(
+            timestamp_with_milliseconds
+                .fractional_seconds_scale()
+                .unwrap(),
+            3
+        );
+
+        // Set a fractional seconds as Decimal with low precision
+        let timestamp_with_seconds =
+            Timestamp::with_ymd_hms(2021, 4, 6, 10, 15, 0).build_at_offset(-5 * 60)?;
+
+        // For low precision fractional_seconds_scale should return a None
+        assert_eq!(timestamp_with_seconds.fractional_seconds_scale(), None);
+        Ok(())
+    }
+
     #[test]
     fn test_first_n_digits_of() {
         assert_eq!(0, super::first_n_digits_of(1, 0));
@@ -1012,7 +1353,7 @@ mod ionc_tests {
         ),
         Timestamp::with_ymd(2020, 1, 1)
             .with_hour_and_minute(0, 1)
-            .build_at_offset(8 * 60 * 60)
+            .build_at_offset(-8 * 60)
             .unwrap()
     )]
     #[case::second_plus0400(
@@ -1023,7 +1364,7 @@ mod ionc_tests {
         ),
         Timestamp::with_ymd(2020, 1, 1)
             .with_hms(0, 1, 23)
-            .build_at_offset(-4 * 60 * 60)
+            .build_at_offset(4 * 60)
             .unwrap()
     )]
     #[case::millis_zulu(
