@@ -273,6 +273,28 @@ pub struct BorrowedStruct<'val> {
     no_text_fields: Vec<(BorrowedSymbolToken<'val>, BorrowedElement<'val>)>,
 }
 
+impl<'val> BorrowedStruct<'val> {
+    fn eq_text_fields(&self, other: &Self) -> bool {
+        // check if both the text_fields have same (field_name,value) pairs
+        self.text_fields.iter().all(|(key, value)| {
+            value
+                .iter()
+                .all(|(_my_s, my_v)| other.get_all(key).any(|other_v| my_v == other_v))
+                && value.len() == other.get_all(key).count()
+        })
+    }
+
+    fn eq_no_text_fields(&self, other: &Self) -> bool {
+        // check if both the no_text_fields are same values
+        self.no_text_fields.iter().all(|(my_k, my_v)| {
+            other
+                .no_text_fields
+                .iter()
+                .any(|(other_k, other_v)| my_k == other_k && my_v == other_v)
+        })
+    }
+}
+
 impl<'val, K, V> FromIterator<(K, V)> for BorrowedStruct<'val>
 where
     K: Into<BorrowedSymbolToken<'val>>,
@@ -290,7 +312,7 @@ where
 
             match key.text() {
                 Some(text) => {
-                    let vals = text_fields.entry(text.into()).or_insert(Vec::new());
+                    let vals = text_fields.entry(text.into()).or_insert_with(Vec::new);
                     vals.push((key, val));
                 }
                 None => {
@@ -318,7 +340,7 @@ impl<'val> Struct for BorrowedStruct<'val> {
         Box::new(
             self.text_fields
                 .values()
-                .flat_map(|v| v)
+                .flatten()
                 .into_iter()
                 .chain(self.no_text_fields.iter())
                 .map(|(s, v)| (s, v)),
@@ -348,22 +370,15 @@ impl<'val> Struct for BorrowedStruct<'val> {
 
 impl<'val> PartialEq for BorrowedStruct<'val> {
     fn eq(&self, other: &Self) -> bool {
-        // check if both the text_fields have same (field_name,value) pairs
-        self.text_fields.iter().all(|(key, value)| {
-            value.iter().all(|(_my_s, my_v)| {
-                other
-                    .get_all(key)
-                    .find(|other_v| my_v == *other_v)
-                    .is_some()
-            })
-        }) && self.no_text_fields.iter().all(|(my_k, my_v)| {
-            // check if both the no_text_fields have same values
-            other
-                .no_text_fields
-                .iter()
-                .find(|(other_k, other_v)| my_k == other_k && my_v == other_v)
-                .is_some()
-        })
+        // check if both text_fields and no_text_fields have same length
+        self.text_fields.len() == other.text_fields.len() && self.no_text_fields.len() == other.no_text_fields.len()
+        // check if text_fields and no_text_fields are equal 
+        // we need to test equality in both directions for both text_fields and no_text_fields
+        // A good example for this is annotated vs not annotated values in struct
+        //  { a:4, a:4 } vs. { a:4, a:a::4 } // returns true
+        //  { a:4, a:a::4 } vs. { a:4, a:4 } // returns false 
+        && self.eq_text_fields(other) && other.eq_text_fields(self)
+            && self.eq_no_text_fields(other) && other.eq_no_text_fields(self)
     }
 }
 
@@ -512,10 +527,7 @@ impl<'val> Element for BorrowedElement<'val> {
     }
 
     fn is_null(&self) -> bool {
-        match &self.value {
-            BorrowedValue::Null(_) => true,
-            _ => false,
-        }
+        matches!(&self.value, BorrowedValue::Null(_))
     }
 
     fn as_any_int(&self) -> Option<&AnyInt> {
@@ -606,8 +618,8 @@ mod borrowed_value_tests {
             text_token("hello").into()
         ),
         case::struct_(
-            BorrowedElement::new_struct(vec![("greetings", BorrowedElement::from(BorrowedValue::String("hello".into())))].into_iter()),
-            BorrowedStruct::from_iter(vec![("greetings", BorrowedElement::from(BorrowedValue::String("hello".into())))].into_iter()).into()
+            BorrowedElement::new_struct(vec![("greetings", BorrowedElement::from(BorrowedValue::String("hello")))].into_iter()),
+            BorrowedStruct::from_iter(vec![("greetings", BorrowedElement::from(BorrowedValue::String("hello")))].into_iter()).into()
         ),
     )]
     fn owned_element_accessors(elem1: BorrowedElement, elem2: BorrowedElement) {
