@@ -153,8 +153,18 @@
 //!
 //! ```
 //! use ion_rs::value::{Element, SymbolToken};
-//! use ion_rs::value::borrowed::{BorrowedValue, BorrowedElement, local_sid_token as borrowed_local_sid_token, text_token as borrowed_text_token};
-//! use ion_rs::value::owned::{OwnedValue, OwnedElement, local_sid_token as owned_local_sid_token, text_token as owned_text_token};
+//! use ion_rs::value::borrowed::{
+//!     BorrowedValue,
+//!     BorrowedElement,
+//!     local_sid_token as borrowed_local_sid_token,
+//!     text_token as borrowed_text_token
+//! };
+//! use ion_rs::value::owned::{
+//!     OwnedValue,
+//!     OwnedElement,
+//!     local_sid_token as owned_local_sid_token,
+//!     text_token as owned_text_token
+//! };
 //!
 //! fn extract_annotations<T: Element>(elem: &T) -> Vec<Option<String>> {
 //!     elem.annotations().map(
@@ -216,9 +226,24 @@ pub trait ImportSource: Debug + PartialEq {
 }
 
 /// A view of a symbolic token.
-/// This can be either a symbol value itself, an annotation, or an field name.
-/// A token may have `text`, a symbol `id`, or both.
-/// here text as `None` represents SID $0
+///
+/// This can be either a content associated with a symbol value itself, an annotation,
+/// or a field name.
+///
+/// A token may have `text`, a symbol `id`, both, or neither.  Optionally, a token may have
+/// some shared import `source` from whence it came.
+///
+/// Symbol `$0`, for example, is represented with a symbol that has no `source`
+/// and no `text`, and whose `local_sid` is `0` (but could also have some other `local_sid` implying
+/// that a symbol with *unknown text* was defined in some local context).
+///
+/// Note that it is context dependent whether a symbol token implementation has had its applicable
+/// context available to it (e.g. the local symbol table).  A low-level implementation of a
+/// symbol token from a raw Ion binary parser, for example, may have symbol tokens in which *only*
+/// the `local_sid` defined because it only deals with the raw encoding of Ion.  A high-level
+/// implementation that end users would generally use could have an symbol tokens that have their
+/// context applied (or available) such that they return their `text` and/or `source` if the
+/// applicable context had/has that information.
 ///
 /// ## `PartialEq` Implementation Notes
 /// Implementations of [`SymbolToken`] that implement [`PartialEq`] should do so without
@@ -262,6 +287,10 @@ pub trait SymbolToken: Debug + PartialEq {
 
     /// The text of the token, which may be `None` if no text is associated with the token
     /// (e.g. lack of a shared symbol table import for a given SID).
+    ///
+    /// An implementation is allowed to return `None` if the text is explicitly known to be
+    /// *undefined* (e.g. `$0`) or the context that would allow it to be defined has not been
+    /// applied or is not available.
     fn text(&self) -> Option<&str>;
 
     /// The ID of the token, which may be `None` if no ID is associated with the token
@@ -269,6 +298,10 @@ pub trait SymbolToken: Debug + PartialEq {
     fn local_sid(&self) -> Option<SymbolId>;
 
     /// The source of this token, which may be `None` if the symbol is locally defined.
+    ///
+    /// An implementation is allowed to return `None` if the source is explicitly known to be
+    /// *undefined* (e.g. a locally defined symbol) or the context that would allow the source
+    /// to be defined has not been applied or is not available.
     fn source(&self) -> Option<&Self::ImportSource>;
 
     /// Decorates the [`SymbolToken`] with text.
@@ -768,7 +801,7 @@ mod generic_value_tests {
     #[case::owned_no_annotations(no_annotations_case::<OwnedElement>())]
     #[case::borrowed_no_annotations(no_annotations_case::<BorrowedElement>())]
     fn annotations_with_element<E: Element>(#[case] input: CaseAnnotations<E>) {
-        let actual: Vec<&E::SymbolToken> = input.elem.annotations().map(|tok| tok).collect();
+        let actual: Vec<&E::SymbolToken> = input.elem.annotations().collect();
         let expected: Vec<&E::SymbolToken> = input.annotations.iter().collect();
         assert_eq!(actual, expected);
     }
@@ -867,6 +900,422 @@ mod generic_value_tests {
         }
     }
 
+    /// A struct that defines input case for `struct_accessors` method
+    struct CaseStruct<E: Element> {
+        /// set of struct elements that are the same
+        eq_annotations: Vec<E>,
+        /// set of struct elements that are never equal to `eq_annotations`
+        ne_annotations: Vec<E>,
+    }
+
+    fn struct_with_local_sid_case<E: Element>() -> CaseStruct<E>
+    where
+        E::Builder: Builder<SymbolToken = E::SymbolToken>,
+    {
+        CaseStruct {
+            eq_annotations: vec![
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(21),
+                        E::Builder::new_string("hello"),
+                    )]
+                    .into_iter(),
+                ),
+                // SymbolToken with local SID and no text are equivalent to each other and to SID $0
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(22),
+                        E::Builder::new_string("hello"),
+                    )]
+                    .into_iter(),
+                ),
+            ],
+            ne_annotations: vec![
+                // structs with different symbol token values
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(21).with_text("foo"),
+                        E::Builder::new_string("hello"),
+                    )]
+                    .into_iter(),
+                ),
+                // struct with annotated value
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(21),
+                        E::Builder::new_string("hello")
+                            .with_annotations(vec![E::SymbolToken::text_token("foo")]),
+                    )]
+                    .into_iter(),
+                ),
+                // struct with different value for (field,value) pair
+                E::Builder::new_struct(
+                    vec![(E::SymbolToken::local_sid_token(21), E::Builder::new_i64(10))]
+                        .into_iter(),
+                ),
+                // structs with different fields length
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::local_sid_token(21),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::local_sid_token(21),
+                            E::Builder::new_string("hi"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+        }
+    }
+
+    fn struct_with_import_source_case<E: Element>() -> CaseStruct<E>
+    where
+        E::Builder: Builder<SymbolToken = E::SymbolToken>,
+    {
+        CaseStruct {
+            eq_annotations: vec![
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(21).with_source("hello_table", 2),
+                        E::Builder::new_string("hello"),
+                    )]
+                    .into_iter(),
+                ),
+                // SymbolToken with local SID and no text are equivalent to each other and to SID $0
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(22).with_source("hello_table", 2),
+                        E::Builder::new_string("hello"),
+                    )]
+                    .into_iter(),
+                ),
+            ],
+            ne_annotations: vec![
+                // structs with different symbol token sources
+                E::Builder::new_struct(
+                    vec![(
+                        E::SymbolToken::local_sid_token(21).with_source("hey_table", 2),
+                        E::Builder::new_string("hello"),
+                    )]
+                    .into_iter(),
+                ),
+                // structs with different fields length
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::local_sid_token(21).with_source("hello_table", 2),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::local_sid_token(21),
+                            E::Builder::new_string("hi"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+        }
+    }
+
+    fn struct_with_multiple_fields_case<E: Element>() -> CaseStruct<E>
+    where
+        E::Builder: Builder<SymbolToken = E::SymbolToken>,
+    {
+        CaseStruct {
+            eq_annotations: vec![
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("name"),
+                            E::Builder::new_string("Ion"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with different order of fields
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("name"),
+                            E::Builder::new_string("Ion"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+            ne_annotations: vec![
+                // structs with different length and duplicates
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("name"),
+                            E::Builder::new_string("Ion"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with different fields length and duplicates
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("name"),
+                            E::Builder::new_string("Ion"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("bye"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with different fields length
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("name"),
+                            E::Builder::new_string("Ion"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("message"),
+                            E::Builder::new_string("bye"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+        }
+    }
+
+    fn struct_with_duplicates_in_multiple_fields_case<E: Element>() -> CaseStruct<E>
+    where
+        E::Builder: Builder<SymbolToken = E::SymbolToken>,
+    {
+        CaseStruct {
+            eq_annotations: vec![
+                E::Builder::new_struct(
+                    vec![
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with different symbol token sids
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("a").with_local_sid(21),
+                            E::Builder::new_i64(1),
+                        ),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with sources
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("a").with_source("hello_table", 22),
+                            E::Builder::new_i64(1),
+                        ),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+            ne_annotations: vec![
+                // structs with different length
+                E::Builder::new_struct(
+                    vec![
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with annotated values
+                E::Builder::new_struct(
+                    vec![
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (
+                            E::SymbolToken::text_token("a"),
+                            E::Builder::new_i64(1)
+                                .with_annotations(vec![E::SymbolToken::text_token("a")]),
+                        ),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with different value for duplicates
+                E::Builder::new_struct(
+                    vec![
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(2)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with no texts but sources
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::local_sid_token(22).with_source("hello_table", 22),
+                            E::Builder::new_i64(1),
+                        ),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                        (E::SymbolToken::text_token("a"), E::Builder::new_i64(1)),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+        }
+    }
+
+    fn struct_with_duplicate_fieldnames_case<E: Element>() -> CaseStruct<E>
+    where
+        E::Builder: Builder<SymbolToken = E::SymbolToken>,
+    {
+        CaseStruct {
+            eq_annotations: vec![
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("world"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with unordered fields
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("world"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+            ne_annotations: vec![
+                // structs with different length and duplicates
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("world"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hey"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with annotated values
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("world")
+                                .with_annotations(vec![E::SymbolToken::text_token("foo")]),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+                // structs with different length
+                E::Builder::new_struct(
+                    vec![
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("hello"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("greetings"),
+                            E::Builder::new_string("world"),
+                        ),
+                        (
+                            E::SymbolToken::text_token("name"),
+                            E::Builder::new_string("hello"),
+                        ),
+                    ]
+                    .into_iter(),
+                ),
+            ],
+        }
+    }
+
+    #[rstest]
+    #[case::owned_struct_with_local_sid(struct_with_local_sid_case::<OwnedElement>())]
+    #[case::borrowed_struct_with_local_sid(struct_with_local_sid_case::<BorrowedElement>())]
+    #[case::owned_struct_with_import_source(struct_with_import_source_case::<OwnedElement>())]
+    #[case::borrowed_struct_with_import_source(struct_with_import_source_case::<BorrowedElement>())]
+    #[case::owned_struct_with_multiple_fields(struct_with_multiple_fields_case::<OwnedElement>())]
+    #[case::borrowed_struct_with_multiple_fields(struct_with_multiple_fields_case::<BorrowedElement>())]
+    #[case::owned_struct_with_duplicates_in_multiple_fields(struct_with_duplicates_in_multiple_fields_case::<OwnedElement>())]
+    #[case::borrowed_struct_with_duplicates_in_multiple_fields(struct_with_duplicates_in_multiple_fields_case::<BorrowedElement>())]
+    #[case::owned_struct_with_duplicate_fieldnames(struct_with_duplicate_fieldnames_case::<OwnedElement>())]
+    #[case::borrowed_struct_with_duplicate_fieldnames(struct_with_duplicate_fieldnames_case::<BorrowedElement>())]
+    fn struct_accessors<E: Element>(#[case] input: CaseStruct<E>) {
+        // check if equivalent vector contains set of structs that are all equal
+        for eq_this_struct in &input.eq_annotations {
+            for eq_other_struct in &input.eq_annotations {
+                assert_eq!(eq_this_struct, eq_other_struct);
+            }
+        }
+
+        // check if non_equivalent vector contains a set of structs that are not ever equal
+        // to the equivalent set structs.
+        for eq_struct in &input.eq_annotations {
+            for non_eq_struct in &input.ne_annotations {
+                assert_ne!(eq_struct, non_eq_struct);
+            }
+        }
+    }
+
     /// Models the operations on `Element` that we want to test.
     #[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
     enum ElemOp {
@@ -893,11 +1342,10 @@ mod generic_value_tests {
     }
 
     use std::collections::HashSet;
-    use std::fmt::Debug;
     use std::str::FromStr;
     use ElemOp::*;
 
-    type ElemAssertFunc<E> = dyn Fn(&E) -> ();
+    type ElemAssertFunc<E> = dyn Fn(&E);
 
     struct Case<E: Element> {
         elem: E,
@@ -1167,374 +1615,6 @@ mod generic_value_tests {
             }),
         }
     }
-
-    fn struct_with_local_sid_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![(
-                    E::SymbolToken::local_sid_token(21),
-                    E::Builder::new_string("hello"),
-                )]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let expected = E::Builder::new_struct(
-                    vec![(
-                        E::SymbolToken::local_sid_token(21),
-                        E::Builder::new_string("hello"),
-                    )]
-                    .into_iter(),
-                );
-                assert_eq!(actual, expected.as_struct());
-            }),
-        }
-    }
-
-    // SymbolToken with local SID and no text are equivalent to each other and to SID $0
-    fn struct_with_different_local_sid_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![(
-                    E::SymbolToken::local_sid_token(21),
-                    E::Builder::new_string("hello"),
-                )]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let expected = E::Builder::new_struct(
-                    vec![(
-                        E::SymbolToken::local_sid_token(22),
-                        E::Builder::new_string("hello"),
-                    )]
-                    .into_iter(),
-                );
-                assert_eq!(actual, expected.as_struct());
-            }),
-        }
-    }
-
-    fn struct_with_import_source_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![(
-                    E::SymbolToken::local_sid_token(21).with_source("hello_table", 2),
-                    E::Builder::new_string("hello"),
-                )]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let expected = E::Builder::new_struct(
-                    vec![(
-                        E::SymbolToken::local_sid_token(21).with_source("hello_table", 2),
-                        E::Builder::new_string("hello"),
-                    )]
-                    .into_iter(),
-                );
-                assert_eq!(actual, expected.as_struct());
-            }),
-        }
-    }
-
-    fn struct_with_import_source_not_equal_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![(
-                    E::SymbolToken::local_sid_token(21).with_source("hello_table", 2),
-                    E::Builder::new_string("hello"),
-                )]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let expected = E::Builder::new_struct(
-                    vec![(
-                        E::SymbolToken::local_sid_token(21).with_source("hey_table", 2),
-                        E::Builder::new_string("hello"),
-                    )]
-                    .into_iter(),
-                );
-                assert_ne!(actual, expected.as_struct());
-            }),
-        }
-    }
-
-    fn struct_with_multiple_fields_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("hello"),
-                    ),
-                    (
-                        E::SymbolToken::text_token("name"),
-                        E::Builder::new_string("Ion"),
-                    ),
-                ]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct().unwrap();
-                // expected struct has unordered struct
-                let unordered_struct = E::Builder::new_struct(
-                    vec![
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("hello"),
-                        ),
-                        (
-                            E::SymbolToken::text_token("name"),
-                            E::Builder::new_string("Ion"),
-                        ),
-                    ]
-                    .into_iter(),
-                );
-                let expected = unordered_struct.as_struct().unwrap();
-                assert_eq!(actual.get("name"), expected.get("name"));
-                assert_eq!(actual.get("greetings"), expected.get("greetings"));
-                assert_eq!(actual, expected);
-            }),
-        }
-    }
-
-    fn struct_with_unordered_multiple_fields_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("hello"),
-                    ),
-                    (
-                        E::SymbolToken::text_token("name"),
-                        E::Builder::new_string("Ion"),
-                    ),
-                ]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct().unwrap();
-                // expected struct has unordered struct
-                let unordered_struct = E::Builder::new_struct(
-                    vec![
-                        (
-                            E::SymbolToken::text_token("name"),
-                            E::Builder::new_string("Ion"),
-                        ),
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("hello"),
-                        ),
-                    ]
-                    .into_iter(),
-                );
-                let expected = unordered_struct.as_struct().unwrap();
-                assert_eq!(actual.get("name"), expected.get("name"));
-                assert_eq!(actual.get("greetings"), expected.get("greetings"));
-                assert_eq!(actual, expected);
-            }),
-        }
-    }
-
-    fn struct_with_multiple_fields_not_equal_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("hello"),
-                    ),
-                    (
-                        E::SymbolToken::text_token("name"),
-                        E::Builder::new_string("Ion"),
-                    ),
-                ]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct().unwrap();
-                // expected struct with different value for field name: "greetings"
-                let not_equal_struct = E::Builder::new_struct(
-                    vec![
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("hey"),
-                        ),
-                        (
-                            E::SymbolToken::text_token("name"),
-                            E::Builder::new_string("Ion"),
-                        ),
-                    ]
-                    .into_iter(),
-                );
-                let expected = not_equal_struct.as_struct().unwrap();
-                assert_eq!(actual.get("name"), expected.get("name"));
-                assert_ne!(actual.get("greetings"), expected.get("greetings"));
-                assert_ne!(actual, expected);
-            }),
-        }
-    }
-
-    fn struct_with_text_and_duplicates_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("hello"),
-                    ),
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("world"),
-                    ),
-                ]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let struct_with_duplicates = E::Builder::new_struct(
-                    vec![
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("hello"),
-                        ),
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("world"),
-                        ),
-                    ]
-                    .into_iter(),
-                );
-                let expected = struct_with_duplicates.as_struct();
-                assert_eq!(actual, expected);
-            }),
-        }
-    }
-
-    fn struct_with_unordered_text_and_duplicates_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("hello"),
-                    ),
-                    (
-                        E::SymbolToken::text_token("greetings"),
-                        E::Builder::new_string("world"),
-                    ),
-                ]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let unordered_struct = E::Builder::new_struct(
-                    vec![
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("world"),
-                        ),
-                        (
-                            E::SymbolToken::text_token("greetings"),
-                            E::Builder::new_string("hello"),
-                        ),
-                    ]
-                    .into_iter(),
-                );
-                let expected = unordered_struct.as_struct();
-                assert_eq!(actual, expected);
-            }),
-        }
-    }
-
-    fn struct_with_unordered_no_text_and_duplicates_case<E: Element>() -> Case<E>
-    where
-        E::Builder: Builder<SymbolToken = E::SymbolToken>,
-    {
-        Case {
-            elem: E::Builder::new_struct(
-                vec![
-                    (
-                        E::SymbolToken::local_sid_token(21),
-                        E::Builder::new_string("hello"),
-                    ),
-                    (
-                        E::SymbolToken::local_sid_token(21),
-                        E::Builder::new_string("world"),
-                    ),
-                ]
-                .into_iter(),
-            ),
-            ion_type: IonType::Struct,
-            ops: vec![AsStruct],
-            op_assert: Box::new(|e: &E| {
-                let actual = e.as_struct();
-                let unordered_struct = E::Builder::new_struct(
-                    vec![
-                        (
-                            E::SymbolToken::local_sid_token(21),
-                            E::Builder::new_string("world"),
-                        ),
-                        (
-                            E::SymbolToken::local_sid_token(21),
-                            E::Builder::new_string("hello"),
-                        ),
-                    ]
-                    .into_iter(),
-                );
-                let expected = unordered_struct.as_struct();
-                assert_eq!(actual, expected);
-            }),
-        }
-    }
     // TODO add more tests to remove the separate Owned/Borrowed tests and only keep generic tests
 
     #[rstest]
@@ -1572,26 +1652,6 @@ mod generic_value_tests {
     #[case::borrowed_symbol_with_import_source(symbol_with_import_source_case::<BorrowedElement>())]
     #[case::owned_symbol_with_import_source_and_text(symbol_with_import_source_and_text_case::<OwnedElement>())]
     #[case::borrowed_symbol_with_import_source_and_text(symbol_with_import_source_and_text_case::<BorrowedElement>())]
-    #[case::owned_struct_with_local_sid(struct_with_local_sid_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_local_sid(struct_with_local_sid_case::<BorrowedElement>())]
-    #[case::owned_struct_with_different_local_sid(struct_with_different_local_sid_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_different_local_sid(struct_with_different_local_sid_case::<BorrowedElement>())]
-    #[case::owned_struct_with_import_source(struct_with_import_source_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_import_source(struct_with_import_source_case::<BorrowedElement>())]
-    #[case::owned_struct_with_import_source_not_equal(struct_with_import_source_not_equal_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_import_source_not_equal(struct_with_import_source_not_equal_case::<BorrowedElement>())]
-    #[case::owned_struct_with_multiple_fields(struct_with_multiple_fields_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_multiple_fields(struct_with_multiple_fields_case::<BorrowedElement>())]
-    #[case::owned_struct_with_unordered_multiple_fields(struct_with_unordered_multiple_fields_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_unordered_multiple_fields(struct_with_unordered_multiple_fields_case::<BorrowedElement>())]
-    #[case::owned_struct_with_multiple_fields_not_equal(struct_with_multiple_fields_not_equal_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_multiple_fields_not_equal(struct_with_multiple_fields_not_equal_case::<BorrowedElement>())]
-    #[case::owned_struct_with_text_and_duplicates(struct_with_text_and_duplicates_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_text_and_duplicates(struct_with_text_and_duplicates_case::<BorrowedElement>())]
-    #[case::owned_struct_with_unordered_text_and_duplicates(struct_with_unordered_text_and_duplicates_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_unordered_text_and_duplicates(struct_with_unordered_text_and_duplicates_case::<BorrowedElement>())]
-    #[case::owned_struct_with_unordered_no_text_and_duplicates(struct_with_unordered_no_text_and_duplicates_case::<OwnedElement>())]
-    #[case::borrowed_struct_with_unordered_no_text_and_duplicates(struct_with_unordered_no_text_and_duplicates_case::<BorrowedElement>())]
     fn element_accessors<E: Element>(#[case] input_case: Case<E>) {
         // table of negative assertions for each operation
         let neg_table: Vec<(ElemOp, &ElemAssertFunc<E>)> = vec![
