@@ -98,12 +98,9 @@ impl<'a> IonCSliceElementWriter<'a> {
         if let Some(annotations) = annotations_opt {
             // get a writing context with the annotations (which could be empty)
             let mut af_writer = self.writer.annotations(&annotations);
-            match field_name_opt {
-                Some(field_name) => {
-                    // decorate the annotation context with the field name when we have one
-                    af_writer.field(field_name);
-                }
-                _ => {}
+            if let Some(field_name) = field_name_opt {
+                // decorate the annotation context with the field name when we have one
+                af_writer.field(field_name);
             }
 
             let ion_type = element.ion_type();
@@ -385,7 +382,7 @@ mod writer_tests {
     fn list_case<E: Element>() -> TestCase<E> {
         TestCase {
             element: E::Builder::new_list(vec![E::Builder::new_list(
-                vec![1, 2, 3].into_iter().map(|x| E::Builder::new_i64(x)),
+                vec![1, 2, 3].into_iter().map(E::Builder::new_i64),
             )]),
             binary: ion_binary(&[0xB7, 0xB6, 0x21, 0x01, 0x21, 0x02, 0x21, 0x03]),
             text: b"[[1,2,3]]",
@@ -404,11 +401,7 @@ mod writer_tests {
         TestCase {
             element: E::Builder::new_sexp(vec![
                 E::Builder::new_symbol(E::SymbolToken::text_token("name")),
-                E::Builder::new_sexp(
-                    vec!["a", "b", "c"]
-                        .into_iter()
-                        .map(|x| E::Builder::new_string(x)),
-                ),
+                E::Builder::new_sexp(vec!["a", "b", "c"].into_iter().map(E::Builder::new_string)),
             ]),
             binary: ion_binary(&[0xC9, 0x71, 0x04, 0xC6, 0x81, 0x61, 0x81, 0x62, 0x81, 0x63]),
             text: br#"(name ("a" "b" "c"))"#,
